import { 
  select, 
  csv,
	scaleOrdinal,
  pie,
	arc,
  getBBox,
	sum} from 'd3';

// import React, { useState, useCallback, useEffect } from 'react';
// import ReactDOM from 'react-dom';
// import ReactDropdown from 'react-dropdown';
//import { useData } from './useData';


function pointIsInArc(pt, ptData, d3Arc) {
  // Center of the arc is assumed to be 0,0
  // (pt.x, pt.y) are assumed to be relative to the center
  var r1 = d3Arc.innerRadius()(ptData), // Note: Using the innerRadius
      r2 = d3Arc.outerRadius()(ptData),
      theta1 = d3Arc.startAngle()(ptData),
      theta2 = d3Arc.endAngle()(ptData);

  var dist = pt.x * pt.x + pt.y * pt.y,
      angle = Math.atan2(pt.x, -pt.y); // Note: different coordinate system.

  angle = (angle < 0) ? (angle + Math.PI * 2) : angle;

  return (r1 * r1 <= dist) && (dist <= r2 * r2) && 
         (theta1 <= angle) && (angle <= theta2);
}

const render = (data, selector) => {
  const width = 960;
	const height = 400;
	const radius = Math.min(width, height) / 2;
  
  const plot_container = select('.' + selector)
  	.append("div")
  	.attr("class", "helper_div")

 	const plotVariable = d => d.DEPARTURE_DELAY;
  
  const colorScale = scaleOrdinal().domain(['1', '2', '3', '4', '5', '6', '7', '8']).range(['#0277bd','#0fa4fc','#039cf7','#0397ef','#0287d6','#0277bd','#026baa','#025f96']);

  
  const pie_calc = pie()
  	.value(plotVariable)(data);  
  
  const arc = d3.arc()
		.outerRadius(radius - 10)
		.innerRadius(radius - 125);
  
  
  const g = plot_container
  .append('svg')
  	.attr('width', width)
  	.attr('height', height)
  .selectAll('arc').append('g')
  	.data(pie_calc)
  	.enter().append('g')
  	.attr('transform', `translate(${width/2}, ${height/2})`)
  	.attr('class', 'pie-slice');
  
  g.append('path')
		.attr('d', arc)
		.style('fill', d => colorScale(d.data.AIRLINE));

  
}

csv('https://gist.githubusercontent.com/josvin92/9a6b89cb9365b1042d6648fc584c3198/raw/Flight_Delay.csv').then(data => {
  data.forEach(d => {
    d.DEPARTURE_DELAY = +d.DEPARTURE_DELAY; 
			// console.log(d.DEPARTURE_DELAY);
  });
  
  const dataByAirlineDelay = d3.nest()
  	.key(function(d) {return d.AIRLINE;})
  	.rollup(function(v){return d3.sum(v, function(d) { return d.DEPARTURE_DELAY; });})
  	.entries(data)
  	.map(d => {
    	return {
        AIRLINE: d.key,
        DEPARTURE_DELAY: d.value}
      })
    
  // dataByAirlineDelay.forEach(function(element) {
  //     console.log(element);
  //   });
// console.log(JSON.stringify(dataByDelay15));  
  render(dataByAirlineDelay, 'plot_container');
});